pub struct StatusProxy<'p>(Proxy<'p>);Tuple Fields
0: Proxy<'p>Implementations
Sourceimpl<'p> StatusProxy<'p>
impl<'p> StatusProxy<'p>
Sourcepub async fn new(conn: &Connection) -> Result<StatusProxy<'p>>
pub async fn new(conn: &Connection) -> Result<StatusProxy<'p>>
Creates a new proxy with the default service and path.
Sourcepub fn builder(conn: &Connection) -> Builder<'p, Self>
pub fn builder(conn: &Connection) -> Builder<'p, Self>
Returns a customizable builder for this proxy.
Sourcepub fn into_inner(self) -> Proxy<'p>
pub fn into_inner(self) -> Proxy<'p>
Consumes self, returning the underlying zbus::Proxy.
Sourcepub fn inner_mut(&mut self) -> &mut Proxy<'p>
pub fn inner_mut(&mut self) -> &mut Proxy<'p>
The mutable reference to the underlying zbus::Proxy.
Sourcepub async fn is_enabled(&self) -> Result<bool>
pub async fn is_enabled(&self) -> Result<bool>
IsEnabled property
Sourcepub fn cached_is_enabled(
&self,
) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
pub fn cached_is_enabled( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
IsEnabled property
Get the cached value of the IsEnabled property, or None if the property is not cached.
Sourcepub async fn receive_is_enabled_changed(
&self,
) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
pub async fn receive_is_enabled_changed( &self, ) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
IsEnabled property
Create a stream for the IsEnabled property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
pub async fn set_is_enabled(&self, value: bool) -> Result<()>
Sourcepub async fn screen_reader_enabled(&self) -> Result<bool>
pub async fn screen_reader_enabled(&self) -> Result<bool>
ScreenReaderEnabled property
Sourcepub fn cached_screen_reader_enabled(
&self,
) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
pub fn cached_screen_reader_enabled( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
ScreenReaderEnabled property
Get the cached value of the ScreenReaderEnabled property, or None if the property is not cached.
Sourcepub async fn receive_screen_reader_enabled_changed(
&self,
) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
pub async fn receive_screen_reader_enabled_changed( &self, ) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
ScreenReaderEnabled property
Create a stream for the ScreenReaderEnabled property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
pub async fn set_screen_reader_enabled(&self, value: bool) -> Result<()>